# Snapshot report for `test/js/clientRegistrationTest.js`

The actual snapshot is saved in `clientRegistrationTest.js.snap`.

Generated by [AVA](https://ava.li).

## structure

> Snapshot 1

    ServiceRequest {
      clientRegistration: ClientRegistration {
        name: 'clientName',
        namespace: 'app',
      },
    }
